Package: SSVS
Title: Functions for Stochastic Search Variable Selection (SSVS)
Version: 2.2.0
Authors@R: c(person(given="Sierra",
         family="Bainter",
         role=c("cre", "aut"),
         email="sbainter@miami.edu",
         comment=c(ORCID="0000-0001-7461-0803")),
  person(given="Thomas",
         family="McCauley",
         role=c("aut"),
         email="thomasgranvillemccauley@gmail.com"),
  person(given="Mahmoud",
         family="Fahmy",
         role=c("aut"),
         email="mahmoud.m.fahm@gmail.com"),
  person("Dean", "Attali", 
         role = "aut",
         email = "daattali@gmail.com", 
         comment= c(ORCID="0000-0002-5645-3493")))
Description: Functions for performing stochastic search variable selection (SSVS) 
    for binary and continuous outcomes and visualizing the results. 
    SSVS is a Bayesian variable selection method used to estimate the probability 
    that individual predictors should be included in a regression model. 
    Using MCMC estimation, the method samples thousands of regression models 
    in order to characterize the model uncertainty regarding both the predictor 
    set and the regression parameters. For details see Bainter, McCauley, Wager, 
    and Losin (2020) Improving practices for selecting a subset of important 
    predictors in psychology: An application to predicting pain, Advances in 
    Methods and Practices in Psychological Science 3(1), 66-80 
    <DOI:10.1177/2515245919885617>.
URL: https://github.com/sabainter/SSVS
BugReports: https://github.com/sabainter/SSVS/issues
Depends: R (>= 4.5.0)
Imports: bayestestR, BoomSpikeSlab, checkmate, ggplot2, graphics,
        rlang, stats, dplyr, magrittr, gridExtra
Suggests: AER, bslib, foreign, glue, knitr, mice, psych, reactable,
        readxl, rmarkdown, scales, shiny, shinyjs, shinyWidgets,
        testthat (>= 3.0.0), tools, utils
License: GPL-3
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.3
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-04-09 20:44:30 UTC; sbainter
Author: Sierra Bainter [cre, aut] (ORCID:
    <https://orcid.org/0000-0001-7461-0803>),
  Thomas McCauley [aut],
  Mahmoud Fahmy [aut],
  Dean Attali [aut] (ORCID: <https://orcid.org/0000-0002-5645-3493>)
Maintainer: Sierra Bainter <sbainter@miami.edu>
Repository: CRAN
Date/Publication: 2026-04-09 21:00:09 UTC
Built: R 4.5.2; ; 2026-04-15 05:10:28 UTC; unix
