# Generated by roxygen2: do not edit by hand

S3method(plot,ssvs)
S3method(plot,ssvs_mi)
S3method(print,ssvs_mi_summary)
S3method(print,ssvs_summary)
S3method(summary,ssvs)
S3method(summary,ssvs_mi)
export("%>%")
export(launch)
export(ssvs)
export(ssvs_mi)
importFrom(magrittr,"%>%")
importFrom(rlang,.data)
