#### The purpose of SSVS, and how to use this tool:

The overall goal of SSVS is to provide information about the relative importance of predictors, accounting for uncertainty in which other predictors are included in the model. SSVS samples thousands of regression models in order to characterize the model uncertainty regarding both the predictor set and the regression parameters. The models are selected using a sampling process that is designed to select among “good” models, that is, models with high probability.

After sampling, rather than selecting the best model according to a specified criterion (e.g., the best Akaike’s or Bayesian information criterion or the highest model R2), researchers can examine the proportion of times each predictor was selected, which provides information about which predictors reliably predict the outcome, accounting for uncertainty in the other predictors in the model. Please see Bainter, McCauley, Wager, and Losin (2020) for more details.

The key quantity obtained by SSVS is the marginal inclusion probability (MIP), which is the proportion of times each predictor was included in the sampled models. Predictors with higher MIPs are consistent predictors of the dependent variable, accounting for uncertainty in the other variables included in the models.

<br/>

#### How to cite:

This web tool may be cited in APA style as:

Bainter, S. A., McCauley, T. G., Wager, T., & Losin, E. A. R. (2020). Improving practices for selecting a subset of important predictors in psychology: An application to predicting pain. Advances in Methods in Psychological Science, 3(1), 66-80. https://doi.org/10.1177/2515245919885617

<br/>

#### Contact us

If you encounter any problems, please contact us at ssvsforpsych@gmail.com
